==> jtharness_4.6.orig.tar.xz: jtharness-4.6/src/com/sun/javatest/agent/ModeOptions.java <==
/*
 * $Id$
 *
 * Copyright (c) 1996, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.agent;

import java.awt.GridBagLayout;
import java.awt.Panel;
import java.awt.TextField;

abstract class ModeOptions extends Panel {
    ModeOptions(String modeName) {
        setLayout(new GridBagLayout());
        this.modeName = modeName;
    }

    String getModeName() {
        return modeName;
    }

    abstract ConnectionFactory createConnectionFactory(int concurrency)
        throws BadValue, ConnectionFactory.Fault;

    protected static int getInt(String label, TextField field) throws BadValue {
        try {
            return Integer.parseInt(field.getText(), 10);
        }
        catch (NumberFormatException e) {
            throw new BadValue("bad value in `" + label + "' field");
        }
    }

    private String modeName;
}

==> jtharness_6.0-b24.orig.tar.xz: jtharness-6.0-b24/src/com/sun/javatest/agent/ModeOptions.java <==
/*
 * $Id$
 *
 * Copyright (c) 1996, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.agent;

import java.awt.GridBagLayout;
import java.awt.Panel;
import java.awt.TextField;

abstract class ModeOptions extends Panel {
    private String modeName;

    ModeOptions(String modeName) {
        setLayout(new GridBagLayout());
        this.modeName = modeName;
    }

    protected static int getInt(String label, TextField field) throws BadValue {
        try {
            return Integer.parseInt(field.getText(), 10);
        } catch (NumberFormatException e) {
            throw new BadValue("bad value in `" + label + "' field");
        }
    }

    String getModeName() {
        return modeName;
    }

    abstract ConnectionFactory createConnectionFactory(int concurrency)
            throws BadValue, ConnectionFactory.Fault;
}
